@@ -21,6 +21,9 @@ class matter:
         self.half_life = None
         self.atomic_mass = None
         self.surface_area = None
+        self.delta_temp = None
+        self.momentum = None
+        self.spec_heat = None
 
     def setCharge(self, electrons):
         e = 1.602e-19
@@ -63,7 +66,12 @@ class matter:
 
     def setVolumeRectPrism(self, length, w, h):
         self.volume = length * w * h
-
+    
+    def setMomentum(self):
+        if not self.mass or not self.velocity:
+            raise TypeError("Please set the velocity and mass first")
+        self.momentum = self.mass * self.velocity
+        
     def setDensity(self, mass):
         if not self.volume:
             raise TypeError("Please set the volume of the object before attempting to set density.")
@@ -84,6 +92,14 @@ class matter:
         vz = (z2 - z1) / (t2 - t1)
         speed = math.sqrt(vx ** 2 + vy ** 2 + vz ** 2)
         self.inst_speed = speed
+        
+    def getGravityConst(self):
+        # returns gravitational constant in m^3 kg^-1 s^-2.
+        return 6.6743e-11
+    
+    def getLightSpeed(self):
+        # returns speed of light in meters per second
+        return 299792458
 
     def setMass(self, mass):
         self.mass = mass
@@ -149,14 +165,56 @@ class matter:
 
     def getLocalGravity(self):
         return self.gravitational_force
-
+    
+    def getMomentum(self):
+        if not self.momentum:
+            return "You have not set momentum"
+        else:
+            return self.momentum
+        
     def getGasPressure(self, gas_density):
         # temp is in Kelvin
         return gas_density * self.gasConst * self.temp
 
     def getVolts(self):
         return self.voltage
-
+    
+    def getElementName(self):
+        if not self.atomic_number:
+            return "you have not set the atomic number"
+        
+        element_names = [
+            "Hydrogen", "Helium", "Lithium", "Beryllium", "Boron",
+            "Carbon", "Nitrogen", "Oxygen", "Fluorine", "Neon",
+            "Sodium", "Magnesium", "Aluminum", "Silicon", "Phosphorus",
+            "Sulfur", "Chlorine", "Argon", "Potassium", "Calcium",
+            "Scandium", "Titanium", "Vanadium", "Chromium", "Manganese",
+            "Iron", "Cobalt", "Nickel", "Copper", "Zinc",
+            "Gallium", "Germanium", "Arsenic", "Selenium", "Bromine",
+            "Krypton", "Rubidium", "Strontium", "Yttrium", "Zirconium",
+            "Niobium", "Molybdenum", "Technetium", "Ruthenium", "Rhodium",
+            "Palladium", "Silver", "Cadmium", "Indium", "Tin",
+            "Antimony", "Tellurium", "Iodine", "Xenon", "Cesium",
+            "Barium", "Lanthanum", "Cerium", "Praseodymium", "Neodymium",
+            "Promethium", "Samarium", "Europium", "Gadolinium", "Terbium",
+            "Dysprosium", "Holmium", "Erbium", "Thulium", "Ytterbium",
+            "Lutetium", "Hafnium", "Tantalum", "Tungsten", "Rhenium",
+            "Osmium", "Iridium", "Platinum", "Gold", "Mercury",
+            "Thallium", "Lead", "Bismuth", "Polonium", "Astatine",
+            "Radon", "Francium", "Radium", "Actinium", "Thorium",
+            "Protactinium", "Uranium", "Neptunium", "Plutonium", "Americium",
+            "Curium", "Berkelium", "Californium", "Einsteinium", "Fermium",
+            "Mendelevium", "Nobelium", "Lawrencium", "Rutherfordium", "Dubnium",
+            "Seaborgium", "Bohrium", "Hassium", "Meitnerium", "Darmstadtium",
+            "Roentgenium", "Copernicium", "Nihonium", "Flerovium", "Moscovium",
+            "Livermorium", "Tennessine", "Oganesson"
+        ]
+        if self.atomic_number < 1 or self.atomic_number > 118:
+            return None
+        else:
+            return element_names[self.atomic_number - 1]
+        
+        
     @staticmethod
     def returnConsts():
         return {'BOLTZMANN_CONSTANT': 1.380649e-23,
@@ -250,4 +308,15 @@ class matter:
         sigma = 5.670367e-8  # Stefan-Boltzmann constant
         L = 4 * math.pi * (radius ** 2) * sigma * (self.temp ** 4)
         return L
-
+    
+    def setSpecificHeatCapacity(self, cap):
+        self.spec_heat = cap
+    
+    def setDeltaTemp(self, temp):
+        self.delta_temp = temp
+        
+    def getHeatCapacity(self):
+        if not self.delta_temp or not self.spec_heat or not self.mass:
+            return "Some required consts are not defined"
+        
+        return self.mass * self.spec_heat * self.delta_temp
